%define anolis_release 2
%global with_debug 0

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider github
%global provider_tld com
%global project opencontainers
%global repo runc
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path %{provider_prefix}

Name: %{repo}
Epoch: 2
Version: 1.1.12
Release: %{anolis_release}%{?dist}
Summary: CLI for running Open Containers
License: ASL 2.0
URL: https://github.com/opencontainers/runc
Source0: https://github.com/opencontainers/runc/archive/refs/tags/v%{version}.tar.gz
Patch0001: 0001-drop-bash-shebang-from-completion.patch
Patch0002: 0002-add-loong64-support-for-func.patch

# These two patches are used to fix CVE-2024-45310
# https://github.com/opencontainers/runc/commit/8781993968fd964ac723ff5f360b6f259e809a3e
Patch0003: 0003-rootfs-consolidate-mountpoint-creation-logic.patch
# https://github.com/opencontainers/runc/commit/f0b652ea61ff6750a8fcc69865d45a7abf37accf
Patch0004: 0004-rootfs-try-to-scope-MkdirAll-to-stay-inside-the-rootfs.patch

BuildRequires: golang
BuildRequires: pkgconfig(libseccomp)
BuildRequires: go-md2man
BuildRequires: make
Provides: oci-runtime
# vendored libraries
# awk '{print "Provides: bundled(golang("$1")) = "$2}' go.mod | sort | uniq | sed -e 's/-/_/g' -e '/bundled(golang())/d' -e '/bundled(golang(go\|module\|replace\|require))/d'
Provides: bundled(golang(github.com/checkpoint_restore/go_criu/v5)) = v5.3.0
Provides: bundled(golang(github.com/cilium/ebpf)) = v0.7.0
Provides: bundled(golang(github.com/containerd/console)) = v1.0.3
Provides: bundled(golang(github.com/coreos/go_systemd/v22)) = v22.3.2
Provides: bundled(golang(github.com/cpuguy83/go_md2man/v2)) = v2.0.0_20190314233015_f79a8a8ca69d
Provides: bundled(golang(github.com/cyphar/filepath_securejoin)) = v0.2.4
Provides: bundled(golang(github.com/docker/go_units)) = v0.4.0
Provides: bundled(golang(github.com/godbus/dbus/v5)) = v5.0.6
Provides: bundled(golang(github.com/moby/sys/mountinfo)) = v0.5.0
Provides: bundled(golang(github.com/mrunalp/fileutils)) = v0.5.1
Provides: bundled(golang(github.com/opencontainers/runtime_spec)) = v1.0.3_0.20210326190908_1c3f411f0417
Provides: bundled(golang(github.com/opencontainers/selinux)) = v1.10.0
Provides: bundled(golang(github.com/russross/blackfriday/v2)) = v2.0.1
Provides: bundled(golang(github.com/seccomp/libseccomp_golang)) = v0.9.2_0.20220502022130_f33da4d89646
Provides: bundled(golang(github.com/shurcooL/sanitized_anchor_name)) = v1.0.0
Provides: bundled(golang(github.com/sirupsen/logrus)) = v1.8.1
Provides: bundled(golang(github.com/syndtr/gocapability)) = v0.0.0_20200815063812_42c35b437635
Provides: bundled(golang(github.com/urfave/cli)) = v1.22.1
Provides: bundled(golang(github.com/vishvananda/netlink)) = v1.1.0
Provides: bundled(golang(github.com/vishvananda/netns)) = v0.0.0_20191106174202_0a2b9b5464df
Recommends: container-selinux >= 2:2.85-1

%description
The runc command can be used to start containers which are packaged
in accordance with the Open Container Initiative's specifications,
and to manage containers running under runc.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1
sed -i 's/ -trimpath//g' Makefile

%build
%set_build_flags
export CGO_CFLAGS=$CFLAGS
# These extra flags present in $CFLAGS have been skipped for now as they break the build
CGO_CFLAGS=$(echo $CGO_CFLAGS | sed 's/-flto=auto//g')
CGO_CFLAGS=$(echo $CGO_CFLAGS | sed 's/-Wp,D_GLIBCXX_ASSERTIONS//g')
CGO_CFLAGS=$(echo $CGO_CFLAGS | sed 's/-specs=\/usr\/lib\/rpm\/anolis\/anolis-annobin-cc1//g')

%ifarch x86_64
export CGO_CFLAGS+=" -m64 -mtune=generic -fcf-protection=full"
%endif

mkdir -p GOPATH
pushd GOPATH
    mkdir -p src/%{provider}.%{provider_tld}/%{project}
    ln -s $(dirs +1 -l) src/%{import_path}
popd

pushd GOPATH/src/%{import_path}
export GOPATH=$(pwd)/GOPATH

make BUILDTAGS="seccomp selinux" all

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 755 %{name} %{buildroot}%{_bindir}

# generate man pages
man/md2man-all.sh

# install man pages
install -d -p %{buildroot}%{_mandir}/man8
install -p -m 0644 man/man8/*.8 %{buildroot}%{_mandir}/man8/.
# install bash completion
install -d -p %{buildroot}%{_datadir}/bash-completion/completions
install -p -m 0644 contrib/completions/bash/%{name} %{buildroot}%{_datadir}/bash-completion/completions

%generate_compatibility_deps

%files
%license LICENSE
%{_bindir}/%{name}
%dir %{abidir}
%{abidir}/%{name}-option.list
%{_mandir}/man8/%{name}*
%{_datadir}/bash-completion/completions/%{name}

%files doc
%doc MAINTAINERS_GUIDE.md PRINCIPLES.md README.md CONTRIBUTING.md

%changelog
* Wed April 09 2025 tomcruiseqi <qizengtian@inspur.com> - 2:1.1.12-2
- Fix CVE-2024-45310

* Fri Feb 02 2024 Funda Wang <fundawang@yeah.net> - 2:1.1.12-1
- New version 1.1.12

* Wed Oct 18 2023 Funda Wang <fundawang@yeah.net> - 2:1.1.9-1
- New version 1.1.9
- Add loong64 support for runc (Wenlong Zhang <zhangwenlong@loongson.cn>)
- Cleanup spec

* Fri Apr 07 2023 Funda Wang <fundawang@yeah.net> - 2:1.1.5-1
- New version 1.1.5

* Wed Mar 08 2023 yuanhui <yuanhui@linux.alibaba.com> - 2:1.1.4-1
- Update runc to 1.1.4
- Add abi files

* Tue Aug 30 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2:1.1.3-1
- update runc to 1.1.3

* Thu Mar 10 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2:1.1.0-1
- Init from upstream v1.1.0
